@@ -28,6 +28,7 @@ class ContextFilter(wafflehaus.base.WafflehausBase):
         self.strat = conf.get('context_strategy')
         if self.strat is None:
             self.log.info('No context context is configured')
+        self.req_auth = conf.get('require_auth_info')
 
     def _import_class(self, name):
         last_dot = name.rfind(".")
@@ -50,7 +51,7 @@ class ContextFilter(wafflehaus.base.WafflehausBase):
             else:
                 self.log.error("Failed to find strategy: %s" % self.strat)
         if not self.testing:
-            self.strat_instance = kls(self.context_key)
+            self.strat_instance = kls(self.context_key, req_auth=self.req_auth)
             self.strat_instance.load_context(req)
         return self.app
 
@@ -65,8 +66,9 @@ class ContextFilter(wafflehaus.base.WafflehausBase):
 
 class BaseContextStrategy(object):
 
-    def __init__(self, key):
+    def __init__(self, key, req_auth=False):
         self.key = key
+        self.require_auth_info = req_auth
 
     def load_context(self, req):
         pass
